/* Copyright 2017 Silviu-Emil Popescu
 * Solution:
 *
 *      I. D[k][t] = maximum n that can be solved with @k lifes and @t tries
 *
 *      II. D[k][t] = 1 + D[k - 1][t - 1] + D[k][t - 1]
 *
 *      III. minarg_t (D[K][t] >= N)
 *
 *      Observation: lim_k D[k] = 0 1 3 7 15 31 63 ...
 *
 *      Time: O(sqrt(n))
 *      Memory: O(sqrt(n))
 *
 */

#include <stdio.h>
#include <math.h>
#include <vector>
#include <iostream>

using namespace std;

template <class T>
bool is_final(vector<T>& v) {
    for (int i = 1; i < (int) v.size(); ++ i) {
        if (2 * v[i - 1] + 1 != v[i]) {
            return false;
        }
    }
    return true;
}

template <class T>
void init_vect(vector<T>& v) {
    for (int i = 0; i < (int) v.size(); ++ i) {
        v[i] = i;
    }
}

int sol_b(int N, int K) {
    if (K == 1) {
        return N;
    }

    vector<int> D(2 * sqrt(N));
    init_vect(D);

    int ans = D.size() - 1;
    for (int k = 2; k <= K && !is_final(D); ++ k) {
        int val = 0;

        for (int tries = 1; tries <= ans; ++ tries) {
            int aux = val;
            val = D[tries];
            D[tries] = aux + D[tries - 1] + 1;
            if (D[tries] >= N) {
                ans = tries;
                break;
            }
        }

        D.resize(ans + 1);
    }

    return ans;
}

int main() {
    freopen("warriors.in", "r", stdin);
    freopen("warriors.out", "w", stdout);

    int n, k;

    cin >> n >> k;
    cout << sol_b(n, k) << endl;

    return 0;
}
